OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Սխալ գաղտնաբառ",
    "Unable to change password" : "Չկարողացա փոխել գաղտնաբառը",
    "Saved" : "Պահված",
    "Updates" : "Թարմացումներ",
    "Language changed" : "Լեզուն փոխվեց",
    "Delete" : "Ջնջել",
    "Very weak password" : "Շատ թույլ գաղտնաբառ",
    "Weak password" : "Թույլ գաղտնաբառ",
    "So-so password" : "Միջինոտ գաղտնաբառ",
    "Good password" : "Լավ գաղտնաբառ",
    "Strong password" : "Ուժեղ գաղտնաբառ",
    "Groups" : "Խմբեր",
    "never" : "երբեք",
    "add group" : "խումբ ավելացնել",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "days" : "օր",
    "Cancel" : "Չեղարկել",
    "Email" : "Էլ. հասցե",
    "Password" : "Գաղտնաբառ",
    "New password" : "Նոր գաղտնաբառ",
    "Change password" : "Փոխել գաղտնաբառը",
    "Language" : "Լեզու",
    "Help translate" : "Օգնել թարգմանել",
    "Name" : "Անուն",
    "Username" : "Օգտանուն",
    "Group" : "Խումբ",
    "Other" : "Այլ"
},
"nplurals=2; plural=(n != 1);");
